@@ -1,5 +1,5 @@
-/* $XConsortium: button.c,v 1.66 91/05/31 17:00:03 gildea Exp $ */
-/* $Id: button.c,v 5.1 1992/12/08 05:45:55 kagotani Rel $ */
+/* $XConsortium: button.c /main/70 1996/01/14 16:52:34 kaleb $ */
+/* $Id: button.c,v 6.2 1996/07/02 05:01:31 kagotani Rel $ */
 /*
  * Copyright 1987 by Digital Equipment Corporation, Maynard, Massachusetts.
  *
@@ -101,7 +101,11 @@ static int saveStartRRow, saveStartRCol, saveEndRRow, saveEndRCol;
 
 /* Multi-click handling */
 static int numberOfClicks = 0;
+#ifdef ENBUG /* kagotani */
 static long int lastButtonUpTime = 0;
+#else
+static Time lastButtonUpTime = 0;
+#endif
 typedef int SelectUnit;
 #define SELECTCHAR 0
 #define SELECTWORD 1
@@ -363,9 +367,9 @@ int *format;
 	int (*func)();
 	int n;
 	int convCStoJIS();
-# ifdef KTERM_KANJI
+# ifdef KTERM_KANJIMODE
 	int convCStoEUC(), convCStoSJIS();
-# endif /* KTERM_KANJI */
+# endif /* KTERM_KANJIMODE */
 	Ichr cbuf[256 + 1];
 
 	n = convCTtoCS(ct, *length, NULL);
@@ -377,7 +381,7 @@ int *format;
 	cs = (n > 256) ? (Ichr *)XtMalloc((n + 1) * sizeof(Ichr)) : cbuf;
 	(void)convCTtoCS(ct, *length, cs);
 
-# ifdef KTERM_KANJI
+# ifdef KTERM_KANJIMODE
 	switch (((XtermWidget)w)->flags & (EUC_KANJI|SJIS_KANJI)) {
 	case EUC_KANJI:
 	    func = convCStoEUC;
@@ -389,9 +393,9 @@ int *format;
 	    func = convCStoJIS;
 	    break;
 	}
-# else /* !KTERM_KANJI */
+# else /* !KTERM_KANJIMODE */
 	func = convCStoJIS;
-# endif /* !KTERM_KANJI */
+# endif /* !KTERM_KANJIMODE */
 
 	n = (*func)(cs, NULL);
 	line = (n > 256) ? XtMalloc(n + 1) : lbuf;
@@ -403,7 +407,7 @@ int *format;
 	int n = *length;
 
 	line = (n > 256) ? XtMalloc(n + 1) : lbuf;
-	bcopy((char *)value, line, n);
+	memmove( line, (char *)value, n);
 	line[n] = '\0';
 	p = (char *) value;
 	q = line;
@@ -455,11 +459,15 @@ Cardinal *num_params;
 
 static void
 SetSelectUnit(buttonDownTime, defaultUnit)
-    unsigned long buttonDownTime;
+    Time buttonDownTime;
     SelectUnit defaultUnit;
 {
+#ifdef ENBUG /* kagotani */
 /* Do arithmetic as integers, but compare as unsigned solves clock wraparound */
 	if ((long unsigned)((long int)buttonDownTime - lastButtonUpTime)
+#else
+	if (buttonDownTime - lastButtonUpTime
+#endif
 	 > term->screen.multiClickTime) {
 		numberOfClicks = 1;
 		selectUnit = defaultUnit;
@@ -535,8 +543,9 @@ TrackDown(event)
 			else if (x >= screen->max_row) \
 			    x = screen->max_row;
 
+void
 TrackMouse(func, startrow, startcol, firstrow, lastrow)
-int func, startrow, startcol, firstrow, lastrow;
+    int func, startrow, startcol, firstrow, lastrow;
 {
 	TScreen *screen = &term->screen;
 
@@ -768,56 +777,35 @@ Cardinal *num_params;		/* unused */
 }
 
 
-
-
-
 ScrollSelection(screen, amount)
 register TScreen* screen;
 register int amount;
 {
-    register int minrow = -screen->savedlines;
+    register int minrow = -screen->savedlines - screen->topline;
+    register int maxrow = screen->max_row - screen->topline;
+    register int maxcol = screen->max_col;
 
-    /* Sent by scrollbar stuff, so amount never takes selection out of
-       saved text */
+#define scroll_update_one(row, col) \
+	row += amount; \
+	if (row < minrow) { \
+	    row = minrow; \
+	    col = 0; \
+	} \
+	if (row > maxrow) { \
+	    row = maxrow; \
+	    col = maxcol; \
+	}
 
-    /* XXX - the preceeding is false; cat /etc/termcap (or anything
-       larger than the number of saved lines plus the screen height) and then
-       hit extend select */
+    scroll_update_one(startRRow, startRCol);
+    scroll_update_one(endRRow, endRCol);
+    scroll_update_one(startSRow, startSCol);
+    scroll_update_one(endSRow, endSCol);
 
-    startRRow += amount; endRRow += amount;
-    startSRow += amount; endSRow += amount;
-    rawRow += amount;
-    screen->startHRow += amount;
-    screen->endHRow += amount;
+    scroll_update_one(rawRow, rawCol);
+
+    scroll_update_one(screen->startHRow, screen->startHCol);
+    scroll_update_one(screen->endHRow, screen->endHCol);
 
-    if (startRRow < minrow) {
-	startRRow = minrow;
-	startRCol = 0;
-    }
-    if (endRRow < minrow) {
-	endRRow = minrow;
-        endRCol = 0;
-    }
-    if (startSRow < minrow) {
-	startSRow = minrow;
-	startSCol = 0;
-    }
-    if (endSRow < minrow) {
-	endSRow = minrow;
-	endSCol = 0;
-    }
-    if (rawRow < minrow) {
-	rawRow = minrow;
-	rawCol = 0;
-    }
-    if (screen->startHRow < minrow) {
-	screen->startHRow = minrow;
-	screen->startHCol = 0;
-    }
-    if (screen->endHRow < minrow) {
-	screen->endHRow = minrow;
-	screen->endHCol = 0;
-    }
     screen->startHCoord = Coordinate (screen->startHRow, screen->startHCol);
     screen->endHCoord = Coordinate (screen->endHRow, screen->endHCol);
 }
@@ -1347,7 +1335,7 @@ ReHiliteText(frow, fcol, trow, tcol)
 	}
 }
 
-static _OwnSelection();
+static void _OwnSelection();
 
 static void
 SaltTextAway(crow, ccol, row, col, params, num_params)
@@ -1484,7 +1472,7 @@ int *format;
 	*targetP++ = XA_COMPOUND_TEXT(d);
 	*targetP++ = XA_LENGTH(d);
 	*targetP++ = XA_LIST_LENGTH(d);
-	bcopy((char*)std_targets, (char*)targetP, sizeof(Atom)*std_length);
+	memmove( (char*)targetP, (char*)std_targets, sizeof(Atom)*std_length);
 	XtFree((char*)std_targets);
 	*type = XA_ATOM;
 	*format = 32;
@@ -1523,7 +1511,7 @@ int *format;
 	    *(long*)*value = 1;
 	else {
 	    long temp = 1;
-	    bcopy( ((char*)&temp)+sizeof(long)-4, (char*)*value, 4);
+	    memmove( (char*)*value, ((char*)&temp)+sizeof(long)-4, 4);
 	}
 	*type = XA_INTEGER;
 	*length = 1;
@@ -1544,7 +1532,7 @@ int *format;
 #else /* !KTERM */
 	    long temp = xterm->screen.selection_length;
 #endif /* !KTERM */
-	    bcopy( ((char*)&temp)+sizeof(long)-4, (char*)*value, 4);
+	    memmove( (char*)*value, ((char*)&temp)+sizeof(long)-4, 4);
 	}
 	*type = XA_INTEGER;
 	*length = 1;
@@ -1614,7 +1602,7 @@ Atom *selection, *target;
 #endif /* !KTERM */
 
 
-static /* void */ _OwnSelection(termw, selections, count)
+static void _OwnSelection(termw, selections, count)
     register XtermWidget termw;
     String *selections;
     Cardinal count;
@@ -1788,7 +1776,7 @@ SaveText(screen, row, scol, ecol, lp, eol)
 	}
 	for (i = scol; i < ecol; i++) {
 #ifdef KTERM
-		c = ch[i].code & ~NEEDMAP;
+		c = ch[i].code & 0x7f;
 		g = ch[i].gset;
 		if (c < ' ' || c == 0x7f && !(g & CS96)) {
 			lp->code = ' ';
@@ -1844,6 +1832,7 @@ EditorButton(event)
 }
 
 
+#ifndef KTERM_NOTEK
 /*ARGSUSED*/
 void HandleGINInput (w, event, param_list, nparamsp)
     Widget w;
@@ -1858,15 +1847,16 @@ void HandleGINInput (w, event, param_list, nparamsp)
 	  case 'L': case 'M': case 'R':
 	    break;
 	  default:
-	    Bell ();			/* let them know they goofed */
-	    c = 'l';			/* provide a default */
+	    Bell (XkbBI_MinorError,0);	/* let them know they goofed */
+	    c = 'l';				/* provide a default */
 	}
 	TekEnqMouse (c | 0x80);
 	TekGINoff();
     } else {
-	Bell ();
+	Bell (XkbBI_MinorError,0);
     }
 }
+#endif /* !KTERM_NOTEK */
 
 
 /* ARGSUSED */
