@@ -1,17 +1,30 @@
-/* $XConsortium: menu.c,v 1.62 93/02/25 17:21:30 gildea Exp $ */
-/* $Id: menu.c,v 5.2 1993/11/25 10:32:20 kagotani Rel $ */
+/* $XConsortium: menu.c,v 1.63 94/04/17 20:23:30 gildea Exp $ */
+/* $XConsortium: menu.c /main/64 1996/01/14 16:52:55 kaleb $ */
 /*
-Copyright 1989 Massachusetts Institute of Technology
 
-Permission to use, copy, modify, distribute, and sell this software and its
-documentation for any purpose is hereby granted without fee, provided that
-the above copyright notice appear in all copies and that both that
-copyright notice and this permission notice appear in supporting
-documentation, and that the name of M.I.T. not be used in advertising or
-publicity pertaining to distribution of the software without specific,
-written prior permission.  M.I.T. makes no representations about the
-suitability of this software for any purpose.  It is provided "as is"
-without express or implied warranty.
+Copyright (c) 1989  X Consortium
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of the X Consortium shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from the X Consortium.
+
 */
 
 #include "ptyx.h"
@@ -19,6 +32,9 @@ without express or implied warranty.
 #include "menu.h"
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
+#ifdef KTERM_XIM
+#include <X11/Xlocale.h>
+#endif /* KTERM_XIM */
 #include <X11/Xmu/CharSet.h>
 #include <X11/Xaw/SimpleMenu.h>
 #include <X11/Xaw/SmeBSB.h>
@@ -41,19 +57,28 @@ static void do_securekbd(), do_allowsends(), do_visualbell(),
     do_terminate(), do_kill(), do_quit(), do_scrollbar(), do_jumpscroll(),
     do_reversevideo(), do_autowrap(), do_reversewrap(), do_autolinefeed(),
     do_appcursor(), do_appkeypad(), do_scrollkey(), do_scrollttyoutput(),
+#ifdef KTERM_NOTEK
+    do_allow132(), do_cursesemul(), do_marginbell(),
+    do_altscreen(), do_softreset(), do_hardreset(), do_clearsavedlines(),
+    do_vtfont();
+#else /* !KTERM_NOTEK */
     do_allow132(), do_cursesemul(), do_marginbell(), do_tekshow(), 
     do_altscreen(), do_softreset(), do_hardreset(), do_clearsavedlines(),
     do_tekmode(), do_vthide(), 
     do_tektextlarge(), do_tektext2(), do_tektext3(), do_tektextsmall(), 
     do_tekpage(), do_tekreset(), do_tekcopy(), do_vtshow(), do_vtmode(), 
     do_tekhide(), do_vtfont();
+#endif /* !KTERM_NOTEK */
 #ifdef STATUSLINE
 static void do_statusline(), do_reversestatus();
 #endif /* STATUSLINE */
-#ifdef KTERM_KANJI
+#ifdef KTERM_KANJIMODE
 static void do_eucmode();
 static void do_sjismode();
-#endif /* KTERM_KANJI */
+#endif /* KTERM_KANJIMODE */
+#ifdef KTERM_XIM
+static void do_openim();
+#endif /* KTERM_XIM */
 
 
 /*
@@ -96,24 +121,31 @@ MenuEntry vtMenuEntries[] = {
     { "softreset",	do_softreset, NULL },		/* 16 */
     { "hardreset",	do_hardreset, NULL },		/* 17 */
     { "clearsavedlines",do_clearsavedlines, NULL },	/* 18 */
+#ifndef KTERM_NOTEK
     { "line2",		NULL, NULL },			/* 19 */
     { "tekshow",	do_tekshow, NULL },		/* 20 */
     { "tekmode",	do_tekmode, NULL },		/* 21 */
-#if defined(STATUSLINE) || defined(KTERM_KANJI)
+#endif /* !KTERM_NOTEK */
+#if defined(STATUSLINE) || defined(KTERM)
+# ifndef KTERM_NOTEK
     { "vthide",		do_vthide, NULL },		/* 22 */
+# endif /* !KTERM_NOTEK */
     { "line3",		NULL, NULL },			/* 23 */
 # ifdef STATUSLINE
     { "statusline",	do_statusline, NULL },		/* 24 */
     { "reversestatus",	do_reversestatus, NULL },	/* 25 */
 # endif /* STATUSLINE */
-# ifdef KTERM_KANJI
+# ifdef KTERM_KANJIMODE
     { "eucmode",	do_eucmode, NULL },		/* 24 or 26 */
     { "sjismode",	do_sjismode, NULL },		/* 25 or 27 */
-# endif /* KTERM_KANJI */
+# endif /* KTERM_KANJIMODE */
+# ifdef KTERM_XIM
+    { "openim",		do_openim, NULL },		/* 24, 26 or 28 */
+# endif /* KTERM_XIM */
     };
-#else /* !STATUSLINE && !KTERM_KANJI */
+#else /* !STATUSLINE && !KTERM */
     { "vthide",		do_vthide, NULL }};		/* 22 */
-#endif /* !STATUSLINE && !KTERM_KANJI */
+#endif /* !STATUSLINE && !KTERM */
 
 MenuEntry fontMenuEntries[] = {
     { "fontdefault",	do_vtfont, NULL },		/*  0 */
@@ -127,6 +159,7 @@ MenuEntry fontMenuEntries[] = {
     { "fontsel",	do_vtfont, NULL }};		/*  8 */
     /* this should match NMENUFONTS in ptyx.h */
 
+#ifndef KTERM_NOTEK
 MenuEntry tekMenuEntries[] = {
     { "tektextlarge",	do_tektextlarge, NULL },	/*  0 */
     { "tektext2",	do_tektext2, NULL },		/*  1 */
@@ -140,6 +173,7 @@ MenuEntry tekMenuEntries[] = {
     { "vtshow",		do_vtshow, NULL },		/*  9 */
     { "vtmode",		do_vtmode, NULL },		/* 10 */
     { "tekhide",	do_tekhide, NULL }};		/* 11 */
+#endif /* !KTERM_NOTEK */
 
 static Widget create_menu();
 extern Widget toplevel;
@@ -168,12 +202,9 @@ static Bool domenu (w, event, params, param_count)
     Cardinal *param_count;      /* 0 or 1 */
 {
     TScreen *screen = &term->screen;
-#ifdef KTERM
-    int fnum = F_ISO8859_1; /* menu_font_names */
-#endif /* KTERM */
 
     if (*param_count != 1) {
-	XBell (XtDisplay(w), 0);
+	Bell(XkbBI_MinorError,0);
 	return False;
     }
 
@@ -225,10 +256,13 @@ static Bool domenu (w, event, params, param_count)
 	    set_reversestatus_sensitivity();
 	    update_reversestatus();
 #endif /* STATUSLINE */
-#ifdef KTERM_KANJI
+#ifdef KTERM_KANJIMODE
 	    update_eucmode();
 	    update_sjismode();
-#endif /* KTERM_KANJI */
+#endif /* KTERM_KANJIMODE */
+#ifdef KTERM_XIM
+	    update_openim();
+#endif /* KTERM_XIM */
 	}
 	break;
 
@@ -238,18 +272,33 @@ static Bool domenu (w, event, params, param_count)
 					    fontMenuEntries,
 					    NMENUFONTS);  
 	    set_menu_font (True);
+#ifdef KTERM
+	    set_sensitivity (screen->fontMenu,
+			     fontMenuEntries[fontMenu_fontescape].widget,
+			     (screen->menu_font_list[fontMenu_fontescape]
+			      ? TRUE : FALSE));
+#else /* !KTERM */
 	    set_sensitivity (screen->fontMenu,
 			     fontMenuEntries[fontMenu_fontescape].widget,
 			     (screen->menu_font_names[fontMenu_fontescape]
 			      ? TRUE : FALSE));
+#endif /* !KTERM */
 	}
 	FindFontSelection (NULL, True);
+#ifdef KTERM
+	set_sensitivity (screen->fontMenu,
+			 fontMenuEntries[fontMenu_fontsel].widget,
+			 (screen->menu_font_list[fontMenu_fontsel]
+			  ? TRUE : FALSE));
+#else /* !KTERM */
 	set_sensitivity (screen->fontMenu,
 			 fontMenuEntries[fontMenu_fontsel].widget,
 			 (screen->menu_font_names[fontMenu_fontsel]
 			  ? TRUE : FALSE));
+#endif /* !KTERM */
 	break;
 
+#ifndef KTERM_NOTEK
       case 't':
 	if (!screen->tekMenu) {
 	    screen->tekMenu = create_menu (term, toplevel, "tekMenu",
@@ -258,9 +307,10 @@ static Bool domenu (w, event, params, param_count)
 	    set_tekfont_menu_item (screen->cur.fontsize, TRUE);
 	}
 	break;
+#endif /* !KTERM_NOTEK */
 
       default:
-	XBell (XtDisplay(w), 0);
+	Bell(XkbBI_MinorError,0);
 	return False;
     }
 
@@ -308,6 +358,10 @@ static Widget create_menu (xtw, toplevelw, name, entries, nentries)
     TScreen *screen = &xtw->screen;
     static XtCallbackRec cb[2] = { { NULL, NULL }, { NULL, NULL }};
     static Arg arg = { XtNcallback, (XtArgVal) cb };
+#ifdef KTERM_XIM
+    char *locale, localebuf[256];
+    int len;
+#endif /* KTERM_XIM */
 
     if (screen->menu_item_bitmap == None) {
 	screen->menu_item_bitmap =
@@ -316,6 +370,14 @@ static Widget create_menu (xtw, toplevelw, name, entries, nentries)
 				 (char *)check_bits, check_width, check_height);
     }
 
+#ifdef KTERM_XIM
+    if ((len = strlen(setlocale(LC_CTYPE, NULL))) < 256)
+	locale = localebuf;
+    else
+	locale = XtMalloc(len + 1);
+    strcpy(locale, setlocale(LC_CTYPE, NULL));
+    setlocale(LC_CTYPE, "");
+#endif /* KTERM_XIM */
     m = XtCreatePopupShell (name, simpleMenuWidgetClass, toplevelw, NULL, 0);
 
     for (; nentries > 0; nentries--, entries++) {
@@ -327,6 +389,11 @@ static Widget create_menu (xtw, toplevelw, name, entries, nentries)
 						  smeLineObjectClass), m,
 						 &arg, (Cardinal) 1);
     }
+#ifdef KTERM_XIM
+    setlocale(LC_CTYPE, locale);
+    if (locale != localebuf)
+	XtFree(locale);
+#endif /* KTERM_XIM */
 
     /* do not realize at this point */
     return m;
@@ -369,7 +436,7 @@ static void do_securekbd (gw, closure, data)
 	if (XGrabKeyboard (screen->display, term->core.window,
 			   True, GrabModeAsync, GrabModeAsync, time)
 	    != GrabSuccess) {
-	    XBell (screen->display, 100);
+	    Bell(XkbBI_MinorError, 100);
 	} else {
 	    ReverseVideo (term);
 	    screen->grabbedKbd = TRUE;
@@ -636,6 +703,7 @@ static void do_marginbell (gw, closure, data)
 }
 
 
+#ifndef KTERM_NOTEK
 static void handle_tekshow (gw, allowswitch)
     Widget gw;
     Bool allowswitch;
@@ -648,7 +716,7 @@ static void handle_tekshow (gw, allowswitch)
 	set_tek_visibility (FALSE);
 	end_tek_mode ();		/* WARNING: this does a longjmp */
     } else
-      Bell();
+      Bell(XkbBI_MinorError, 0);
 }
 
 /* ARGSUSED */
@@ -666,6 +734,7 @@ static void do_tekonoff (gw, closure, data)
 {
     handle_tekshow (gw, False);
 }
+#endif /* !KTERM_NOTEK */
 
 /* ARGSUSED */
 static void do_altscreen (gw, closure, data)
@@ -704,6 +773,7 @@ static void do_clearsavedlines (gw, closure, data)
 }
 
 
+#ifndef KTERM_NOTEK
 static void do_tekmode (gw, closure, data)
     Widget gw;
     caddr_t closure, data;
@@ -720,6 +790,7 @@ static void do_vthide (gw, closure, data)
 {
     hide_vt_window();
 }
+#endif /* !KTERM_NOTEK */
 
 #ifdef STATUSLINE
 static void do_statusline (gw, closure, data)
@@ -728,7 +799,7 @@ static void do_statusline (gw, closure, data)
 {
     register TScreen *screen = &term->screen;
 
-    if (screen->statusline) {
+    if (screen->statusheight) {
 	HideStatus();
     } else {
 	ShowStatus();
@@ -749,7 +820,8 @@ static void do_reversestatus (gw, closure, data)
     ScrnRefresh(screen, screen->max_row+1, 0, 1, screen->max_col+1, False);
 }
 #endif /* STATUSLINE */
-#ifdef KTERM_KANJI
+
+#ifdef KTERM_KANJIMODE
 static void do_jismode (gw, closure, data)
     Widget gw;
     caddr_t closure, data;
@@ -761,6 +833,7 @@ static void do_jismode (gw, closure, data)
     screen->gsets[0] = GSET_ASCII;
     screen->gsets[1] = GSET_KANA;
     screen->gsets[2] = GSET_ASCII;
+    screen->gsets[3] = GSET_ASCII;
     screen->curgr = 1;
     update_eucmode();
     update_sjismode();
@@ -781,6 +854,7 @@ static void do_eucmode (gw, closure, data)
 	screen->gsets[0] = GSET_ASCII;
 	screen->gsets[1] = GSET_KANJI;
 	screen->gsets[2] = GSET_KANA;
+	screen->gsets[3] = GSET_HOJOKANJI;
 	screen->curgr = 1;
 	update_eucmode();
 	update_sjismode();
@@ -802,12 +876,30 @@ static void do_sjismode (gw, closure, data)
 	screen->gsets[0] = GSET_ASCII;
 	screen->gsets[1] = GSET_KANA;
 	screen->gsets[2] = GSET_ASCII;
+	screen->gsets[3] = GSET_ASCII;
 	screen->curgr = 1;
 	update_eucmode();
 	update_sjismode();
     }
 }
-#endif /* KTERM_KANJI */
+#endif /* KTERM_KANJIMODE */
+
+#ifdef KTERM_XIM
+static void do_openim (gw, closure, data)
+    Widget gw;
+    caddr_t closure, data;
+{
+    register TScreen *screen = &term->screen;
+    extern void CloseIM(), OpenIM();
+
+    if (screen->imregistered) {
+	CloseIM(screen);
+    } else {
+	OpenIM(screen);
+    }
+    /* update_openim() is done in CloseIM() and OpenIM(). */
+}
+#endif /* KTERM_XIM */
 
 
 /*
@@ -827,10 +919,11 @@ static void do_vtfont (gw, closure, data)
 	    return;
 	}
     }
-    Bell();
+    Bell(XkbBI_MinorError, 0);
 }
 
 
+#ifndef KTERM_NOTEK
 /*
  * tek menu
  */
@@ -905,7 +998,7 @@ static void handle_vtshow (gw, allowswitch)
 	if (!screen->TekEmu && TekRefresh) dorefresh ();
 	end_vt_mode ();
     } else 
-      Bell();
+      Bell(XkbBI_MinorError, 0);
 }
 
 static void do_vtshow (gw, closure, data)
@@ -939,6 +1032,7 @@ static void do_tekhide (gw, closure, data)
 {
     hide_tek_window();
 }
+#endif /* !KTERM_NOTEK */
 
 
 
@@ -969,7 +1063,7 @@ static void handle_toggle (proc, var, params, nparams, w, closure, data)
 
     switch (dir) {
       case -2:
-	Bell();
+	Bell(XkbBI_MinorError, 0);
 	break;
 
       case -1:
@@ -978,12 +1072,12 @@ static void handle_toggle (proc, var, params, nparams, w, closure, data)
 
       case 0:
 	if (var) (*proc) (w, closure, data);
-	else Bell();
+	else Bell(XkbBI_MinorError, 0);
 	break;
 
       case 1:
 	if (!var) (*proc) (w, closure, data);
-	else Bell();
+	else Bell(XkbBI_MinorError, 0);
 	break;
     }
     return;
@@ -1071,7 +1165,7 @@ void HandleSendSignal(w, event, params, param_count)
 	/* one could allow numeric values, but that would be a security hole */
     }
 
-    Bell();
+    Bell(XkbBI_MinorError, 0);
 }
 
 /* ARGSUSED */
@@ -1255,6 +1349,7 @@ void HandleClearSavedLines(w, event, params, param_count)
     do_clearsavedlines(w, NULL, NULL);
 }
 
+#ifndef KTERM_NOTEK
 void HandleSetTerminalType(w, event, params, param_count)
     Widget w;
     XEvent *event;
@@ -1270,10 +1365,10 @@ void HandleSetTerminalType(w, event, params, param_count)
 	    if (!term->screen.TekEmu) do_tekmode (w, NULL, NULL);
 	    break;
 	  default:
-	    Bell();
+	    Bell(XkbBI_MinorError, 0);
 	}
     } else {
-	Bell();
+	Bell(XkbBI_MinorError, 0);
     }
 }
 
@@ -1294,10 +1389,10 @@ void HandleVisibility(w, event, params, param_count)
 			   params+1, (*param_count) - 1, w, NULL, NULL);
 	    break;
 	  default:
-	    Bell();
+	    Bell(XkbBI_MinorError, 0);
 	}
     } else {
-	Bell();
+	Bell(XkbBI_MinorError, 0);
     }
 }
 
@@ -1324,7 +1419,7 @@ void HandleSetTekText(w, event, params, param_count)
 	break;
     }
     if (proc) (*proc) (w, NULL, NULL);
-    else Bell();
+    else Bell(XkbBI_MinorError, 0);
 }
 
 /* ARGSUSED */
@@ -1356,6 +1451,7 @@ void HandleTekCopy(w, event, params, param_count)
 {
     do_tekcopy(w, NULL, NULL);
 }
+#endif /* !KTERM_NOTEK */
 
 
 #ifdef STATUSLINE
@@ -1366,7 +1462,7 @@ void HandleStatusLine(w, event, params, param_count)
     Cardinal *param_count;
 {
     /* eventually want to see if sensitive or not */
-    handle_toggle (do_statusline, (int) term->screen.statusline,
+    handle_toggle (do_statusline, (int) term->screen.statusheight,
 		   params, *param_count, w, NULL, NULL);
 }
 
@@ -1381,7 +1477,8 @@ void HandleStatusReverse(w, event, params, param_count)
 		   params, *param_count, w, NULL, NULL);
 }
 #endif /* STATUSLINE */
-#ifdef KTERM_KANJI
+
+#ifdef KTERM_KANJIMODE
 void HandleSetKanjiMode(w, event, params, param_count)
     Widget w;
     XEvent *event;
@@ -1402,10 +1499,10 @@ void HandleSetKanjiMode(w, event, params, param_count)
 	    do_sjismode (w, NULL, NULL);
 	    break;
 	  default:
-	    Bell();
+	    Bell(XkbBI_MinorError, 0);
 	}
     } else {
-	Bell();
+	Bell(XkbBI_MinorError, 0);
     }
 }
-#endif /* KTERM_KANJI */
+#endif /* KTERM_KANJIMODE */
