@@ -1,8 +1,10 @@
 /*
- *	$XConsortium: ptyx.h,v 1.60.1.1 93/11/03 17:29:39 gildea Exp $
- *	$Id: ptyx.h,v 5.1 1993/11/25 10:32:20 kagotani Rel $
+ *	$XConsortium: ptyx.h /main/66 1995/12/09 08:58:41 kaleb $
+ *	$Id: ptyx.h,v 6.2 1996/07/02 05:01:31 kagotani Rel $
  */
+#ifdef KTERM
 #include "kterm.h"
+#endif /* KTERM */
 
 /*
  * Copyright 1987 by Digital Equipment Corporation, Maynard, Massachusetts.
@@ -69,7 +71,9 @@
 #ifdef hpux
 #define	PTYDEV		"/dev/ptym/ptyxx"
 #else	/* !hpux */
+#ifndef __osf__
 #define	PTYDEV		"/dev/ptyxx"
+#endif
 #endif	/* !hpux */
 #endif	/* !PTYDEV */
 
@@ -77,7 +81,11 @@
 #ifdef hpux
 #define TTYDEV		"/dev/pty/ttyxx"
 #else	/* !hpux */
+#ifdef __osf__
+#define TTYDEV		"/dev/ttydirs/xxx/xxxxxxxxxxxxxx"
+#else
 #define	TTYDEV		"/dev/ttyxx"
+#endif
 #endif	/* !hpux */
 #endif	/* !TTYDEV */
 
@@ -93,10 +101,38 @@
 #ifdef hpux
 #define	PTYCHAR2	"fedcba9876543210"
 #else	/* !hpux */
+#ifdef __FreeBSD__
+#define	PTYCHAR2	"0123456789abcdefghijklmnopqrstuv"
+#else
 #define	PTYCHAR2	"0123456789abcdef"
+#endif
 #endif	/* !hpux */
 #endif	/* !PTYCHAR2 */
 
+#ifndef TTYFORMAT
+#ifdef CRAY
+#define TTYFORMAT "/dev/ttyp%03d"
+#else
+#define TTYFORMAT "/dev/ttyp%d"
+#endif
+#endif
+
+#ifndef PTYFORMAT
+#ifdef CRAY
+#define PTYFORMAT "/dev/pty/%03d"
+#else
+#define PTYFORMAT "/dev/ptyp%d"
+#endif
+#endif
+
+#ifndef MAXPTTYS
+#ifdef CRAY
+#define MAXPTTYS 256
+#else
+#define MAXPTTYS 2048
+#endif
+#endif
+
 /* Until the translation manager comes along, I have to do my own translation of
  * mouse events into the proper routines. */
 
@@ -109,6 +145,10 @@ typedef enum {NORMAL, LEFTEXTENSION, RIGHTEXTENSION} EventMode;
 
 typedef unsigned char Char;		/* to support 8 bit chars */
 
+#ifdef KTERM
+#include "gset.h" /* uses Boolean and Char */
+#endif /* KTERM */
+
 #ifdef KTERM
 typedef struct {
 	Char gset;
@@ -120,6 +160,11 @@ typedef struct {
 # endif /* !KTERM_COLOR */
 } Bchr; /* char for screen buffers */
 typedef Bchr **ScrnBuf;
+
+typedef struct {
+	Char gset;
+	Char code;
+} Ichr; /* char for interchanging with other processes */
 #else /* !KTERM */
 typedef Char **ScrnBuf;
 #endif /* !KTERM */
@@ -179,6 +224,7 @@ typedef struct {
 #endif /* !KTERM */
 } SavedCursor;
 
+#ifndef KTERM_NOTEK
 #define TEK_FONT_LARGE 0
 #define TEK_FONT_2 1
 #define TEK_FONT_3 2
@@ -207,23 +253,17 @@ typedef struct {
 	int width;
 	int height;
 } BitmapBits;
+#endif /* !KTERM_NOTEK */
 
 #define	SAVELINES		64      /* default # lines to save      */
 #define SCROLLLINES 1			/* default # lines to scroll    */
 
 #ifdef KTERM
 # define LINESPACE	0		/* default space between lines	*/
-# define F_ISO8859_1	0
-# define F_JISX0201_0	(F_ISO8859_1 + 1)
-# define SBFCNT		(F_JISX0201_0 + 1) /* number of single byte fonts */
-# ifdef KTERM_MBCS
-#  define F_JISX0208_0	(F_JISX0201_0 + 1)
-#  define FCNT		(F_JISX0208_0 + 1)
-# else
-#  define FCNT		(F_JISX0201_0 + 1)
-# endif
-# define FNUM(gs)	(gsettofnum[gs])
 #endif /* KTERM */
+#ifdef KTERM_XIM
+# define EUCJPLOCALE	"ja_JP.eucJP,ja_JP.ujis,ja_JP.EUC,japanese.euc,Japanese-EUC,ja,japan"
+#endif /* KTERM_XIM */
 
 typedef struct {
 /* These parameters apply to both windows */
@@ -294,11 +334,9 @@ typedef struct {
 #ifdef KTERM
 	XFontStruct	*_fnt_norm[FCNT];
 	XFontStruct	*_fnt_bold[FCNT];
-	int		_enbolden[FCNT];
 	XPoint		*_box[FCNT];
 # define fnt_norm		_fnt_norm[fnum]
 # define fnt_bold		_fnt_bold[fnum]
-# define enbolden		_enbolden[fnum]
 # define box			_box[fnum]
 	int		linespace;	/* space between lines		*/
 	int		max_ascent;
@@ -350,7 +388,8 @@ typedef struct {
 	int		copy_dest_x;
 	int		copy_dest_y;
 	Boolean		c132;		/* allow change to 132 columns	*/
-	Boolean		curses;		/* cludge-ups for more and vi	*/
+	Boolean		curses;		/* kludge line wrap for more	*/
+	Boolean		hp_ll_bc;	/* kludge HP-style ll for xdb	*/
 	Boolean		marginbell;	/* true if margin bell on	*/
 	int		nmarginbell;	/* columns from right margin	*/
 	int		bellarmed;	/* cursor below bell margin	*/
@@ -360,11 +399,10 @@ typedef struct {
 	SavedCursor	sc;		/* data for restore cursor	*/
 	int		save_modes[19];	/* save dec private modes	*/
 #ifdef STATUSLINE
-	Boolean 	statusline;	/* status line showing		*/
-	Boolean 	reversestatus;	/* status line reversed		*/
-	Boolean 	instatus;	/* cursor in status line	*/
 	int	 	statusheight;	/* status line height		*/
+	Boolean 	instatus;	/* cursor in status line	*/
 	SavedCursor 	statussc;	/* status line restore cursor	*/
+	Boolean 	reversestatus;	/* status line reversed		*/
 #endif /* STATUSLINE */
 
 	/* Improved VT100 emulation stuff.				*/
@@ -381,6 +419,7 @@ typedef struct {
 	Boolean		jumpscroll;	/* whether we should jumpscroll */
 	Boolean         always_highlight; /* whether to highlight cursor */
 
+#ifndef KTERM_NOTEK
 /* Tektronix window parameters */
 	GC		TnormalGC;	/* normal painting		*/
 	GC		TcursorGC;	/* normal cursor painting	*/
@@ -410,6 +449,7 @@ typedef struct {
 	int		pen;		/* current Tektronix pen 0=up, 1=dn */
 	char		*TekGIN;	/* nonzero if Tektronix GIN mode*/
 	int		gin_terminator; /* Tek strap option */
+#endif /* !KTERM_NOTEK */
 
 	int		multiClickTime;	 /* time between multiclick selects */
 	int		bellSuppressTime; /* msecs after Bell before another allowed */
@@ -424,7 +464,7 @@ typedef struct {
 #endif /* !KTERM */
 	int		selection_size; /* size of allocated buffer */
 	int		selection_length; /* number of significant bytes */
-	int		selection_time;	/* latest event timestamp */
+	Time		selection_time;	/* latest event timestamp */
 	int		startHRow, startHCol, /* highlighted text */
 			endHRow, endHCol,
 			startHCoord, endHCoord;
@@ -434,8 +474,13 @@ typedef struct {
 	Boolean		input_eight_bits;/* use 8th bit instead of ESC prefix */
 	Boolean		output_eight_bits; /* honor all bits or strip */
 	Pixmap		menu_item_bitmap;	/* mask for checking items */
+#ifdef KTERM_NOTEK
+	Widget		mainMenu, vtMenu, fontMenu;
+#else /* !KTERM_NOTEK */
 	Widget		mainMenu, vtMenu, tekMenu, fontMenu;
+#endif /* !KTERM_NOTEK */
 #ifdef KTERM
+	Boolean		dynamic_font_load; /* load fonts on demand */
 	char*		menu_font_list[NMENUFONTS];
 	char*		menu_bfont_list[NMENUFONTS];
 	char*		_menu_font_names[FCNT][NMENUFONTS];
@@ -446,14 +491,26 @@ typedef struct {
 	char*		menu_font_names[NMENUFONTS];
 #endif /* !KTERM */
 	int		menu_font_number;
+	XIC		xic;
+#ifdef KTERM_XIM
+	XIMStyle	xicstyle;
+	XFontSet	xicfontset;
+	Boolean		imregistered;
+#ifdef INTHEFUTURE
+	Boolean		imserverdied;
+	char		**modifier_list;
+#endif
+#endif /* KTERM_XIM */
 } TScreen;
 
+#ifndef KTERM_NOTEK
 typedef struct _TekPart {
     XFontStruct *Tfont[TEKNUMFONTS];
     int		tobaseline[TEKNUMFONTS]; /* top to baseline for each font */
     char	*initial_font;		/* large, 2, 3, small */
     char	*gin_terminator_str;	/* ginTerminator resource */
 } TekPart;
+#endif /* !KTERM_NOTEK */
 
 
 
@@ -471,17 +528,7 @@ typedef struct
 typedef struct _Misc {
     char *geo_metry;
     char *T_geometry;
-#ifdef KTERM
-    char *fontlist;
-    char *bfontlist;
-    char *_f_n[FCNT];
-    char *_f_b[FCNT];
-# define f_n	_f_n[fnum]
-# define f_b	_f_b[fnum]
-#ifdef KTERM_KANJI
-    char *k_m;
-#endif /* KTERM_KANJI */
-#else /* !KTERM */
+#ifndef KTERM
     char *f_n;
     char *f_b;
 #endif /* !KTERM */
@@ -495,28 +542,49 @@ typedef struct _Misc {
     Boolean autoWrap;
     Boolean logInhibit;
     Boolean signalInhibit;
+#ifndef KTERM_NOTEK
     Boolean tekInhibit;
+#endif /* !KTERM_NOTEK */
     Boolean scrollbar;
     Boolean titeInhibit;
+#ifndef KTERM_NOTEK
     Boolean tekSmall;	/* start tek window in small size */
+#endif /* !KTERM_NOTEK */
     Boolean appcursorDefault;
     Boolean appkeypadDefault;
+#ifdef KTERM_KANJIMODE
+    char *k_m;
+#endif /* KTERM_KANJIMODE */
+#ifdef KTERM_XIM
+    char* eucjp_locale;
+#endif /* !KTERM_XIM */
+    char* input_method;
+    char* preedit_type;
+    Boolean open_im;
+    Boolean shared_ic;
 #ifdef STATUSLINE
+    Boolean statusline;
     Boolean statusnormal;
 #endif /* STATUSLINE */
 } Misc;
 
+#ifdef KTERM_NOTEK
+typedef struct {int foo;} XtermClassPart;
+#else /* !KTERM_NOTEK */
 typedef struct {int foo;} XtermClassPart, TekClassPart;
+#endif /* !KTERM_NOTEK */
 
 typedef struct _XtermClassRec {
     CoreClassPart  core_class;
     XtermClassPart xterm_class;
 } XtermClassRec;
 
+#ifndef KTERM_NOTEK
 typedef struct _TekClassRec {
     CoreClassPart core_class;
     TekClassPart tek_class;
 } TekClassRec;
+#endif /* !KTERM_NOTEK */
 
 /* define masks for flags */
 #define CAPS_LOCK	0x01
@@ -540,10 +608,12 @@ typedef struct _XtermWidgetRec {
     Misc	misc;		/* miscellaneous parameters	*/
 } XtermWidgetRec, *XtermWidget;
 
+#ifndef KTERM_NOTEK
 typedef struct _TekWidgetRec {
     CorePart core;
     TekPart tek;
 } TekWidgetRec, *TekWidget;
+#endif /* !KTERM_NOTEK */
 
 #define BUF_SIZE 4096
 
@@ -589,18 +659,18 @@ typedef struct _TekWidgetRec {
 #endif /* KTERM_COLOR */
 /* global flags */
 #ifdef KTERM
-#define WRAPAROUND	0x40000	/* true if auto wraparound mode */
-#define	REVERSEWRAP	0x80000	/* true if reverse wraparound mode */
+#define WRAPAROUND	0x40000		/* true if auto wraparound mode */
+#define	REVERSEWRAP	0x80000		/* true if reverse wraparound mode */
 #define REVERSE_VIDEO	0x100000	/* true if screen white on black */
 #define LINEFEED	0x200000	/* true if in auto linefeed mode */
 #define ORIGIN		0x400000	/* true if in origin mode */
 #define INSERT		0x800000	/* true if in insert mode */
 #define SMOOTHSCROLL	0x1000000	/* true if in smooth scroll mode */
 #define IN132COLUMNS	0x2000000	/* true if in 132 column mode */
-#ifdef KTERM_KANJI
+#ifdef KTERM_KANJIMODE
 #define	EUC_KANJI	0x4000000	/* true if in EUC mode */
 #define	SJIS_KANJI	0x8000000	/* true if in SJIS mode */
-#endif /* KTERM_KANJI */
+#endif /* KTERM_KANJIMODE */
 #else /* !KTERM */
 #define WRAPAROUND	0x400	/* true if auto wraparound mode */
 #define	REVERSEWRAP	0x800	/* true if reverse wraparound mode */
@@ -616,8 +686,10 @@ typedef struct _TekWidgetRec {
 #define VWindow(screen)		(screen->fullVwin.window)
 #define VShellWindow		term->core.parent->core.window
 #define TextWindow(screen)      (screen->fullVwin.window)
+#ifndef KTERM_NOTEK
 #define TWindow(screen)		(screen->fullTwin.window)
 #define TShellWindow		tekWidget->core.parent->core.window
+#endif /* !KTERM_NOTEK */
 #define Width(screen)		(screen->fullVwin.width)
 #define Height(screen)		(screen->fullVwin.height)
 #define FullWidth(screen)	(screen->fullVwin.fullwidth)
@@ -628,17 +700,20 @@ typedef struct _TekWidgetRec {
 #else /* !KTERM */
 #define FontHeight(screen)	(screen->fullVwin.f_height)
 #endif /* !KTERM */
+#ifndef KTERM_NOTEK
 #define TWidth(screen)		(screen->fullTwin.width)
 #define THeight(screen)		(screen->fullTwin.height)
 #define TFullWidth(screen)	(screen->fullTwin.fullwidth)
 #define TFullHeight(screen)	(screen->fullTwin.fullheight)
 #define TekScale(screen)	(screen->fullTwin.tekscale)
+#endif /* !KTERM_NOTEK */
 
 #define CursorX(screen,col) ((col) * FontWidth(screen) + screen->border \
 			+ screen->scrollbar)
 #ifdef STATUSLINE
-#define CursorY(screen,row) ((((row) - screen->topline) * FontHeight(screen)) \
-			+ screen->border + (screen->instatus ? 1 : 0))
+#define CursorY(screen,row) ((row)>screen->max_row \
+	? (row) * FontHeight(screen) + screen->border * 2 + 1 \
+	: ((row) - screen->topline) * FontHeight(screen) + screen->border)
 #else /* !STATUSLINE */
 #define CursorY(screen,row) ((((row) - screen->topline) * FontHeight(screen)) \
 			+ screen->border)
@@ -651,6 +726,7 @@ typedef struct _TekWidgetRec {
 #define	WINDOWEVENTS	(TWINDOWEVENTS | PointerMotionMask)
 
 
+#ifndef KTERM_NOTEK
 #define TEK_LINK_BLOCK_SIZE 1024
 
 typedef struct Tek_Link
@@ -662,6 +738,7 @@ typedef struct Tek_Link
 	char *ptr;		/* current pointer into data */
 	char data [TEK_LINK_BLOCK_SIZE];
 } TekLink;
+#endif /* !KTERM_NOTEK */
 
 /* flags for cursors */
 #define	OFF		0
@@ -674,7 +751,9 @@ typedef struct Tek_Link
 #define	I_LOG		0x01
 #endif
 #define	I_SIGNAL	0x02
+#ifndef KTERM_NOTEK
 #define	I_TEK		0x04
+#endif /* !KTERM_NOTEK */
 
 extern Cursor make_colored_cursor();
 extern int GetBytesAvailable();
