@@ -1,6 +1,6 @@
 /*
- *	$XConsortium: screen.c,v 1.30 91/08/22 16:27:13 gildea Exp $
- *	$Id: screen.c,v 5.3 1993/11/25 10:32:20 kagotani Rel $
+ *	$XConsortium: screen.c,v 1.33 94/04/02 17:34:36 gildea Exp $
+ *	$Id: screen.c,v 6.3 1996/06/23 08:00:09 kagotani Rel $
  */
 
 /*
@@ -115,18 +115,17 @@ Reallocate(sbuf, sbufaddr, nrow, ncol, oldrow, oldcol)
 	register Bchr *tmp;
 	register int i, minrows, mincols;
 	Bchr *oldbuf;
+# ifdef STATUSLINE
+	Bchr *oldstat;
+# endif /* STATUSLINE */
 #else /* !KTERM */
 	register Char *tmp;
 	register int i, minrows, mincols;
 	Char *oldbuf;
-#endif /* !KTERM */
-#ifdef STATUSLINE
-# ifdef KTERM
-	Bchr *oldstat;
-# else /* !KTERM */
+# ifdef STATUSLINE
 	Char *oldstat;
-# endif /* !KTERM */
-#endif /* STATUSLINE */
+# endif /* STATUSLINE */
+#endif /* !KTERM */
 	int move_down = 0, move_up = 0;
 	
 	if (sbuf == NULL || *sbuf == NULL)
@@ -162,8 +161,8 @@ Reallocate(sbuf, sbufaddr, nrow, ncol, oldrow, oldcol)
 		        - (term->screen.max_row - term->screen.cur_row);
 	    if (move_up < 0)
 		move_up = 0;
-	    /* Overlapping bcopy here! */
-	    bcopy(*sbuf+move_up, *sbuf,
+	    /* Overlapping memmove here! */
+	    memmove( *sbuf, *sbuf+move_up, 
 		  (oldrow-move_up)*sizeof((*sbuf)[0]) );
 	}
 	*sbuf = (ScrnBuf) realloc((char *) (*sbuf),
@@ -176,8 +175,8 @@ Reallocate(sbuf, sbufaddr, nrow, ncol, oldrow, oldcol)
 		        - 2*(term->screen.max_row - term->screen.cur_row);
 	    if (move_up < 0)
 		move_up = 0;
-	    /* Overlapping bcopy here! */
-	    bcopy(*sbuf+move_up, *sbuf,
+	    /* Overlapping memmove here! */
+	    memmove( *sbuf, *sbuf+move_up, 
 		  (oldrow-move_up)*sizeof((*sbuf)[0]) );
 	}
 	*sbuf = (ScrnBuf) realloc((char *) (*sbuf),
@@ -217,7 +216,7 @@ Reallocate(sbuf, sbufaddr, nrow, ncol, oldrow, oldcol)
 	    tmp += ncol*move_down;
 	}
 	for (i = 0; i < minrows; i++, tmp += ncol) {
-		bcopy(base[i], tmp, mincols);
+		memmove( tmp, base[i], mincols);
 	}
 	/*
 	 * update the pointers in sbuf
@@ -226,14 +225,14 @@ Reallocate(sbuf, sbufaddr, nrow, ncol, oldrow, oldcol)
 	    base[i] = tmp;
 
 #ifdef STATUSLINE
-	bcopy(oldstat, tmp, mincols);
+	memmove( tmp, oldstat, mincols);
 	base[nrow] = tmp;
-#ifndef KTERM
+# ifndef KTERM
 	tmp += ncol;
 	oldstat += oldcol;
-	bcopy(oldstat, tmp, mincols);
+	memmove( tmp, oldstat, mincols);
 	base[nrow+1] = tmp;
-#endif /* !KTERM */
+# endif /* !KTERM */
 #endif /* STATUSLINE */
 
         /* Now free the old buffer */
@@ -256,21 +255,26 @@ ScreenWrite (screen, str, flags, length)
    flags.
  */
 TScreen *screen;
+#ifdef KTERM
+Char *str;
+register unsigned flags;
+register Char gset;
+#else /* !KTERM */
 char *str;
 register unsigned flags;
-#ifdef KTERM
-register Char gset;
-#endif /* KTERM */
+#endif /* !KTERM */
 register int length;		/* length of string */
 {
 #ifdef KTERM
 	register int avail  = screen->max_col - screen->cur_col + 1;
-	register Bchr *col;
+	register Bchr *col, *col0;
+	Boolean ontheright = gsetontheright[gset];
 #else /* !KTERM */
-	register Char *attrs;
+	register Char *attrs, *attrs0;
 	register int avail  = screen->max_col - screen->cur_col + 1;
 	register Char *col;
 #endif /* !KTERM */
+	register int wrappedbit;
 
 	if (length > avail)
 	    length = avail;
@@ -278,38 +282,47 @@ register int length;		/* length of string */
 		return;
 
 #ifdef KTERM
-	col = screen->buf[avail = screen->cur_row] + screen->cur_col;
+	col = col0 = screen->buf[avail = screen->cur_row] + screen->cur_col;
+	wrappedbit = col0->attr&LINEWRAPPED;
 #else /* !KTERM */
 	col = screen->buf[avail = 2 * screen->cur_row] + screen->cur_col;
-	attrs = screen->buf[avail + 1] + screen->cur_col;
+	attrs = attrs0 = screen->buf[avail + 1] + screen->cur_col;
+	wrappedbit = *attrs0&LINEWRAPPED;
 #endif /* !KTERM */
 	flags &= ATTRIBUTES;
 	flags |= CHARDRAWN;
 #ifdef KTERM
+# ifdef KTERM_MBCS
 	if (gset & MBCS) {
 		while(length > 0) {
-			col->code = *str++;
+			col->code = ontheright ? *str++|0x80 : *str++&0x7f;
 			col->gset = gset;
 			col->attr = flags;
 			col++;
-			col->code = *str++;
+			col->code = ontheright ? *str++|0x80 : *str++&0x7f;
 			col->gset = MBC2;
 			col->attr = flags;
 			col++;
 			length -= 2;
 		}
-	} else {
+	} else
+# endif /* KTERM_MBCS */
+	{
 		while(length-- > 0) {
-			col->code = *str++;
+			col->code = ontheright ? *str++|0x80 : *str++&0x7f;
 			col->gset = gset;
 			col->attr = flags;
 			col++;
 		}
 	}
-#else /* KTERM */
-	bcopy(str, col, length);
+	if (wrappedbit)
+	    col0->attr |= LINEWRAPPED;
+#else /* !KTERM */
+	memmove( col, str, length);
 	while(length-- > 0)
 		*attrs++ = flags;
+	if (wrappedbit)
+	    *attrs0 |= LINEWRAPPED;
 #endif /* !KTERM */
 }
 
@@ -326,7 +339,9 @@ register int where, n, size;
 {
 	register int i;
 #ifdef KTERM
-	Bchr *save [MAX_ROWS];
+	Bchr *savebuf [MAX_ROWS];
+	Bchr **save;
+	save = n > MAX_ROWS ? (Bchr **)XtMalloc(sizeof(Bchr *) * n) : savebuf;
 #else /* !KTERM */
 	char *save [2 * MAX_ROWS];
 #endif /* !KTERM */
@@ -334,10 +349,10 @@ register int where, n, size;
 
 	/* save n lines at bottom */
 #ifdef KTERM
-	bcopy ((char *) &sb [last -= n - 1], (char *) save,
+	memmove( (char *) save, (char *) &sb [last -= n - 1], 
 		sizeof (Bchr *) * n);
 #else /* !KTERM */
-	bcopy ((char *) &sb [2 * (last -= n - 1)], (char *) save,
+	memmove( (char *) save, (char *) &sb [2 * (last -= n - 1)], 
 		2 * sizeof (char *) * n);
 #endif /* !KTERM */
 	
@@ -360,18 +375,20 @@ register int where, n, size;
 	 *   +--------|---------|----+
 	 */
 #ifdef KTERM
-	bcopy ((char *) &sb [where], (char *) &sb [where + n],
+	memmove( (char *) &sb [where + n], (char *) &sb [where], 
 		sizeof (Bchr *) * (last - where));
 #else /* !KTERM */
-	bcopy ((char *) &sb [2 * where], (char *) &sb [2 * (where + n)],
+	memmove( (char *) &sb [2 * (where + n)], (char *) &sb [2 * where], 
 		2 * sizeof (char *) * (last - where));
 #endif /* !KTERM */
 
 	/* reuse storage for new lines at where */
 #ifdef KTERM
-	bcopy ((char *)save, (char *) &sb[where], sizeof(Bchr *) * n);
+	memmove( (char *) &sb[where], (char *)save, sizeof(Bchr *) * n);
+
+	if (save != savebuf) XtFree((char *)save);
 #else /* !KTERM */
-	bcopy ((char *)save, (char *) &sb[2 * where], 2 * sizeof(char *) * n);
+	memmove( (char *) &sb[2 * where], (char *)save, 2 * sizeof(char *) * n);
 #endif /* !KTERM */
 }
 
@@ -389,16 +406,18 @@ int where;
 {
 	register int i;
 #ifdef KTERM
-	Bchr *save [MAX_ROWS];
+	Bchr *savebuf [MAX_ROWS];
+	Bchr **save;
+	save = n > MAX_ROWS ? (Bchr **)XtMalloc(sizeof(Bchr *) * n) : savebuf;
 #else /* !KTERM */
 	char *save [2 * MAX_ROWS];
 #endif /* !KTERM */
 
 	/* save n lines at where */
 #ifdef KTERM
-	bcopy ((char *) &sb[where], (char *)save, sizeof(Bchr *) * n);
+	memmove( (char *)save, (char *) &sb[where], sizeof(Bchr *) * n);
 #else /* !KTERM */
-	bcopy ((char *) &sb[2 * where], (char *)save, 2 * sizeof(char *) * n);
+	memmove( (char *)save, (char *) &sb[2 * where], 2 * sizeof(char *) * n);
 #endif /* !KTERM */
 
 	/* clear contents of old rows */
@@ -412,18 +431,20 @@ int where;
 
 	/* move up lines */
 #ifdef KTERM
-	bcopy ((char *) &sb[where + n], (char *) &sb[where],
+	memmove( (char *) &sb[where], (char *) &sb[where + n], 
 		sizeof (Bchr *) * ((last -= n - 1) - where));
 #else /* !KTERM */
-	bcopy ((char *) &sb[2 * (where + n)], (char *) &sb[2 * where],
+	memmove( (char *) &sb[2 * where], (char *) &sb[2 * (where + n)], 
 		2 * sizeof (char *) * ((last -= n - 1) - where));
 #endif /* !KTERM */
 
 	/* reuse storage for new bottom lines */
 #ifdef KTERM
-	bcopy ((char *)save, (char *) &sb[last], sizeof(Bchr *) * n);
+	memmove( (char *) &sb[last], (char *)save, sizeof(Bchr *) * n);
+
+	if (save != savebuf) XtFree((char *)save);
 #else /* !KTERM */
-	bcopy ((char *)save, (char *) &sb[2 * last],
+	memmove( (char *) &sb[2 * last], (char *)save, 
 		2 * sizeof(char *) * n);
 #endif /* !KTERM */
 }
@@ -499,13 +520,13 @@ ScrnDeleteChar (sb, row, col, n, size)
 #endif /* !KTERM */
 
 #ifdef KTERM
-	bcopy (ptr + col + n, ptr + col, nbytes * sizeof(Bchr));
+	memmove( ptr + col, ptr + col + n, nbytes * sizeof(Bchr));
 	bzero (ptr + size - n, n * sizeof(Bchr));
 	if (wrappedbit)
 	    ptr[0].attr |= LINEWRAPPED;
 #else /* !KTERM */
-	bcopy (ptr + col + n, ptr + col, nbytes);
-	bcopy (attrs + col + n, attrs + col, nbytes);
+	memmove( ptr + col, ptr + col + n, nbytes);
+	memmove( attrs + col, attrs + col + n, nbytes);
 	bzero (ptr + size - n, n);
 	bzero (attrs + size - n, n);
 	if (wrappedbit)
@@ -525,10 +546,7 @@ register TScreen *screen;
 int toprow, leftcol, nrows, ncols;
 Boolean force;			/* ... leading/trailing spaces */
 {
-#ifdef KTERM
-	XChar2b drawbuf[256], *dbuf;
-	int y = toprow * FontHeight(screen) + screen->border;
-#else /* !KTERM */
+#ifndef KTERM
 	int y = toprow * FontHeight(screen) + screen->border +
 		screen->fnt_norm->ascent;
 #endif /* !KTERM */
@@ -537,35 +555,26 @@ Boolean force;			/* ... leading/trailing spaces */
 	int maxrow = toprow + nrows - 1;
 	int scrollamt = screen->scroll_amt;
 	int max = screen->max_row;
-#ifdef STATUSLINE
-	int dostatus = 0, left, width;
-# ifdef KTERM
-	int fnum = F_ISO8859_1;
-# endif /* KTERM */
-#endif /* STATUSLINE */
 
-#ifdef KTERM
-	dbuf = (ncols > 256) ? (XChar2b *)XtMalloc(ncols * sizeof(XChar2b))
-			     : drawbuf;
-#endif /* KTERM */
 #ifdef STATUSLINE
-	if (screen->statusline && maxrow == screen->max_row + 1) {
-		dostatus++;
-		maxrow--;
-	}
-#endif /* STATUSLINE */
+	if(screen->cursor_col >= leftcol
+	&& screen->cursor_col <= (leftcol + ncols - 1)
+	&& (screen->cursor_row >= toprow + topline
+	 && screen->cursor_row <= maxrow - (maxrow > screen->max_row) + topline
+	 || maxrow > screen->max_row && screen->cursor_row > screen->max_row))
+		screen->cursor_state = OFF;
+#else /* !STATUSLINE */
 	if(screen->cursor_col >= leftcol && screen->cursor_col <=
 	 (leftcol + ncols - 1) && screen->cursor_row >= toprow + topline &&
 	 screen->cursor_row <= maxrow + topline)
 		screen->cursor_state = OFF;
-#ifdef STATUSLINE
-    for (;;) {
-#endif /* STATUSLINE */
-	for (row = toprow; row <= maxrow; y += FontHeight(screen), row++) {
+#endif /* !STATUSLINE */
 #ifdef KTERM
+	for (row = toprow; row <= maxrow; row++) {
 	   register Bchr *chars;
 	   Char gset;
 #else /* !KTERM */
+	for (row = toprow; row <= maxrow; y += FontHeight(screen), row++) {
 	   register Char *chars;
 	   register Char *attrs;
 #endif /* !KTERM */
@@ -573,10 +582,39 @@ Boolean force;			/* ... leading/trailing spaces */
 	   int maxcol = leftcol + ncols - 1;
 	   int lastind;
 	   int flags;
+#ifndef KTERM
 	   int x, n;
 	   GC gc;
+#endif /* !KTERM */
 	   Boolean hilite;	
 
+#ifdef STATUSLINE
+	   if (row > screen->max_row) { /* implies (row > screen->bot_marg) */
+		int dostatus = 0, left, width;
+# ifdef KTERM
+		int fnum = F_ISO8859_1; /* *GC */
+# endif /* KTERM */
+
+		topline = 0;
+		max = screen->max_row + 1; /* statusline buffer */
+
+		left = CursorX(screen, leftcol);
+		width = ncols * FontWidth(screen);
+		if (leftcol == 0) {
+		    left = screen->scrollbar;
+		    width += screen->border;
+		}
+		if (leftcol + ncols - 1 >= screen->max_col)
+		    width += screen->border;
+		XFillRectangle(screen->display, TextWindow(screen),
+		    screen->reversestatus ? screen->normalGC : screen->reverseGC,
+		    left, Height(screen) + screen->border * 2,
+		    width, screen->statusheight);
+		if (!screen->reversestatus)
+		    StatusBox(screen);
+	   }
+#endif /* STATUSLINE */
+
 	   if (row < screen->top_marg || row > screen->bot_marg)
 		lastind = row;
 	   else
@@ -586,7 +624,6 @@ Boolean force;			/* ... leading/trailing spaces */
 	   	continue;
 
 #ifdef KTERM
-	   n = 0;
 	   chars = screen->buf [lastind + topline];
 #else /* !KTERM */
 	   chars = screen->buf [2 * (lastind + topline)];
@@ -654,7 +691,7 @@ Boolean force;			/* ... leading/trailing spaces */
 # ifdef STATUSLINE
 	   if (((!hilite && (flags & INVERSE) != 0) ||
 	        (hilite && (flags & INVERSE) == 0))
-		^ (dostatus < 0 && screen->reversestatus))
+		^ (row > screen->max_row && screen->reversestatus))
 # else /* !STATUSLINE */
 	   if ( (!hilite && (flags & INVERSE) != 0) ||
 	        (hilite && (flags & INVERSE) == 0) )
@@ -664,22 +701,17 @@ Boolean force;			/* ... leading/trailing spaces */
 	   else 
 	       if (flags & BOLD) gc = screen->normalboldGC;
 	       else gc = screen->normalGC;
-#endif /* !KTERM */
 
 	   x = CursorX(screen, col);
+#endif /* !KTERM */
 	   lastind = col;
 
 	   for (; col <= maxcol; col++) {
 #ifdef KTERM
 		if (chars[col].attr != flags || chars[col].gset != gset) {
-# ifdef STATUSLINE
-		   if (hilite ^ (dostatus < 0 && screen->reversestatus))
-# else /* !STATUSLINE */
 		   if (hilite)
-# endif /* !STATUSLINE */
 			flags ^= INVERSE;
-		   ScreenDraw(screen, x, y, dbuf, n, gset, flags, False);
-		   n = 0;
+		   ScreenDraw(screen, row + topline, lastind, col, flags, False);
 #else /* !KTERM */
 		if (attrs[col] != flags) {
 		   XDrawImageString(screen->display, TextWindow(screen), 
@@ -690,9 +722,9 @@ Boolean force;			/* ... leading/trailing spaces */
 		   if(flags & UNDERLINE) 
 			XDrawLine(screen->display, TextWindow(screen), 
 			 gc, x, y+1, x+n*FontWidth(screen), y+1);
-#endif /* !KTERM */
 
 		   x += (col - lastind) * FontWidth(screen);
+#endif /* !KTERM */
 
 		   lastind = col;
 
@@ -700,43 +732,26 @@ Boolean force;			/* ... leading/trailing spaces */
 		   flags = chars[col].attr;
 		   gset = chars[col].gset;
 		}
+
+		if (gset & MBCS) col++;
 #else /* !KTERM */
 		   flags = attrs[col];
 
-#ifdef STATUSLINE
+# ifdef STATUSLINE
 	   	   if (((!hilite && (flags & INVERSE) != 0) ||
 		        (hilite && (flags & INVERSE) == 0))
-			^ (dostatus < 0 && screen->reversestatus))
-#else /* !STATUSLINE */
+			^ (row > screen->max_row && screen->reversestatus))
+# else /* !STATUSLINE */
 	   	   if ((!hilite && (flags & INVERSE) != 0) ||
 		       (hilite && (flags & INVERSE) == 0) )
-#endif /* !STATUSLINE */
+# endif /* !STATUSLINE */
 	       		if (flags & BOLD) gc = screen->reverseboldGC;
 	       		else gc = screen->reverseGC;
 	  	    else 
 	      		 if (flags & BOLD) gc = screen->normalboldGC;
 	      		 else gc = screen->normalGC;
 		}
-#endif /* !KTERM */
 
-#ifdef KTERM
-		/*
-		 * Convert each character to XChar2b.
-		 * If the NEEDMAP flag of the gset is true,
-		 * translate the code on a font used by the gset.
-		 */
-# ifdef KTERM_MBCS
-		if (gset & MBCS) {
-			dbuf[n].byte1 = chars[col++].code;
-			dbuf[n].byte2 = chars[col].code;
-		} else
-# endif /* KTERM_MBCS */
-		{
-			dbuf[n].byte1 = 0;
-			dbuf[n].byte2 = MapOnFont(gset, chars[col].code);
-		}
-		n++;
-#else /* !KTERM */
 		if(chars[col] == 0)
 			chars[col] = ' ';
 #endif /* !KTERM */
@@ -744,19 +759,14 @@ Boolean force;			/* ... leading/trailing spaces */
 
 
 #ifdef KTERM
-# ifdef STATUSLINE
-	   if (hilite ^ (dostatus < 0 && screen->reversestatus))
-# else /* !STATUSLINE */
 	   if (hilite)
-# endif /* !STATUSLINE */
 		flags ^= INVERSE;
-	   ScreenDraw(screen, x, y, dbuf, n, gset, flags, False);
-	   n = 0;
+	   ScreenDraw(screen, row + topline, lastind, col, flags, False);
 #else /* !KTERM */
 # ifdef STATUSLINE
 	   if (((!hilite && (flags & INVERSE) != 0) ||
 	        (hilite && (flags & INVERSE) == 0))
-		^ (dostatus < 0 && screen->reversestatus))
+		^ (row > screen->max_row && screen->reversestatus))
 # else /* !STATUSLINE */
 	   if ( (!hilite && (flags & INVERSE) != 0) ||
 	        (hilite && (flags & INVERSE) == 0) )
@@ -776,37 +786,6 @@ Boolean force;			/* ... leading/trailing spaces */
 		 x, y+1, x + n * FontWidth(screen), y+1);
 #endif /* !KTERM */
 	}
-#ifdef STATUSLINE
-	if (dostatus <= 0)
-		break;
-	dostatus = -1;
-	topline = 0;
-	scrollamt = 0;
-	toprow = maxrow = max = screen->max_row + 1;
-	left = CursorX(screen, leftcol);
-	width = ncols * FontWidth(screen);
-	if (leftcol == 0) {
-		left--;
-		width++;
-	}
-	if (leftcol + ncols - 1 >= screen->max_col)
-		width++;
-	XFillRectangle(screen->display, TextWindow(screen),
-		screen->reversestatus ? screen->normalGC : screen->reverseGC,
-# ifdef KTERM
-		left, y,
-# else /* !KTERM */
-		left, y - screen->fnt_norm->max_bounds.ascent,
-# endif /* !KTERM */
-		width, screen->statusheight);
-	if (!screen->reversestatus)
-		StatusBox(screen);
-	y++;
-    } /* end of for(;;) */
-#endif /* STATUSLINE */
-#ifdef KTERM
-	if (dbuf != drawbuf) XtFree((char *)dbuf);
-#endif /* KTERM */
 }
 
 ClearBufRows (screen, first, last)
@@ -852,7 +831,7 @@ ScreenResize (screen, width, height, flags)
 	int rows, cols;
 	int border = 2 * screen->border;
 	int move_down_by;
-#ifdef sun
+#if defined(sun) && !defined(SVR4)
 #ifdef TIOCSSIZE
 	struct ttysize ts;
 #endif	/* TIOCSSIZE */
@@ -862,18 +841,23 @@ ScreenResize (screen, width, height, flags)
 #endif	/* TIOCSWINSZ */
 #endif	/* sun */
 	Window tw = TextWindow (screen);
-#ifdef STATUSLINE
-	int oldmaxrow = screen->max_row;
-#endif /* STATUSLINE */
 
 	/* clear the right and bottom internal border because of NorthWest
 	   gravity might have left junk on the right and bottom edges */
 	XClearArea (screen->display, tw,
 		    width - screen->border, 0,                /* right edge */
+#ifdef STATUSLINE
+		    screen->border, height - screen->statusheight,
+#else /* !STATUSLINE */
 		    screen->border, height,           /* from top to bottom */
+#endif /* !STATUSLINE */
 		    False);
 	XClearArea (screen->display, tw, 
+#ifdef STATUSLINE
+		    0, height - screen->border - screen->statusheight,
+#else /* !STATUSLINE */
 		    0, height - screen->border,	                  /* bottom */
+#endif /* !STATUSLINE */
 		    width, screen->border,         /* all across the bottom */
 		    False);
 
@@ -889,6 +873,31 @@ ScreenResize (screen, width, height, flags)
 	 FontWidth(screen);
 	if (rows < 1) rows = 1;
 	if (cols < 1) cols = 1;
+#ifdef STATUSLINE
+	if (screen->statusheight
+	 && term->misc.resizeGravity == NorthWestGravity) {
+		/* bit_gravity != ForgetGravity */
+		if (rows > screen->max_row + 1) {
+		    XClearArea (screen->display, tw, 
+				screen->scrollbar,
+				(screen->max_row + 1) * FontHeight(screen) +
+				screen->border * 2,
+				(screen->max_col + 1) * FontHeight(screen) +
+				screen->border * 2,
+				screen->statusheight,
+				True);
+		} else if (rows < screen->max_row + 1) {
+		    XClearArea (screen->display, tw, 
+				screen->scrollbar,
+				rows * FontHeight(screen) +
+				screen->border * 2,
+				cols * FontWidth(screen) + screen->border * 2,
+				screen->statusheight,
+				True);
+		}
+		screen->cursor_state = OFF;
+	}
+#endif /* STATUSLINE */
 
 	/* update buffers if the screen has changed size */
 	if (screen->max_row != rows - 1 || screen->max_col != cols - 1) {
@@ -941,15 +950,6 @@ ScreenResize (screen, width, height, flags)
 		*flags &= ~ORIGIN;
 
 #ifdef STATUSLINE
-		if (screen->statusline) {
-		    if (oldmaxrow > rows - 1)
-			ScrnRefresh(screen, rows, 0, 1, cols, True);
-		    else if (oldmaxrow < rows - 1)
-			XClearArea (screen->display, tw, 
-			    0, (oldmaxrow+1) * FontHeight(screen) + screen->border,
-			    width, screen->statusheight,
-			    False);
-		}
 		if (screen->instatus)
 			screen->cur_row = screen->max_row + 1;
 		else
@@ -959,10 +959,11 @@ ScreenResize (screen, width, height, flags)
 		if (screen->cur_col > screen->max_col)
 			screen->cur_col = screen->max_col;
 	
-		screen->fullVwin.height = height - border;
 #ifdef STATUSLINE
-		screen->fullVwin.height -= screen->statusheight;
-#endif /* STATUSLINE */
+		screen->fullVwin.height = height - border - screen->statusheight;
+#else /* !STATUSLINE */
+		screen->fullVwin.height = height - border;
+#endif /* !STATUSLINE */
 		screen->fullVwin.width = width - border - screen->scrollbar;
 
 	} else if(FullHeight(screen) == height && FullWidth(screen) == width)
@@ -974,7 +975,7 @@ ScreenResize (screen, width, height, flags)
 	screen->fullVwin.fullheight = height;
 	screen->fullVwin.fullwidth = width;
 	ResizeSelection (screen, rows, cols);
-#ifdef sun
+#if defined(sun) && !defined(SVR4)
 #ifdef TIOCSSIZE
 	/* Set tty's idea of window size */
 	ts.ts_lines = rows;
@@ -1007,10 +1008,14 @@ ScreenResize (screen, width, height, flags)
 #endif	/* SIGWINCH */
 #endif	/* TIOCSWINSZ */
 #endif	/* sun */
-#ifdef KTERM_KCONV
-	SendSize();
-	SendSpot();
-#endif /* KTERM_KCONV */
+#ifdef KTERM_XIM
+	IMSendSize(screen);
+	IMSendSpot(screen);
+#endif /* KTERM_XIM */
+#ifdef KTERM_KINPUT2
+	Kinput2SendSize();
+	Kinput2SendSpot();
+#endif /* KTERM_KINPUT2 */
 	return (0);
 }
 
@@ -1121,12 +1126,11 @@ register int row, col, len;
 }
 
 #ifdef KTERM
-ScreenDraw(screen, x, y, dbuf, n, gset, flags, oncursor)
-register TScreen	*screen;
-int	x, y; /* upper-left bound */
-XChar2b	*dbuf;
-int	n;
-Char	gset;
+ScreenDraw(screen, row, col, endcol, flags, oncursor)
+TScreen	*screen;
+int	row; /* in screen->buf */
+int	col;
+int	endcol;
 #ifdef KTERM_COLOR
 unsigned short	flags;
 #else /* !KTERM_COLOR */
@@ -1135,22 +1139,68 @@ Char	flags;
 Boolean	oncursor;
 {
 	GC	gc;
-	int	fnum, cols;
-	Boolean	cursorstate;
+	Boolean	hilitecursor = oncursor && (screen->select || screen->always_highlight);
+	Bchr	*str;
+	Char	gset;
+	int	fnum;	/* for *GC, and box */
+	XChar2b	drawbuf2[256], *dbuf2 = drawbuf2;
+	char	drawbuf[256], *dbuf = drawbuf;
+	int	n, c;
+	int	x, y;
 
-	fnum = FNUM(gset);
-	cols = gset & MBCS ? n * 2 : n;
+	x = CursorX(screen, col);
+	y = CursorY(screen, row);
+	if (row >= screen->top_marg && row <= screen->bot_marg)
+		row -= screen->scroll_amt;
+	str = screen->buf[row];
+# ifdef STATUSLINE
+	if (row > screen->max_row && screen->reversestatus)
+		flags ^= INVERSE;
+# endif /* STATUSLINE */
 
-	cursorstate = oncursor && (screen->select || screen->always_highlight);
+	gset = str[col].gset;
+	fnum = gsettofnum[gset];
+
+# ifdef KTERM_MBCS
+	if (gset & MBCS) {
+		if ((endcol-col+1)/2 > 256)
+			dbuf2 = (XChar2b *)XtMalloc((endcol-col+1)/2 * sizeof(XChar2b));
+		for (c = col, n = 0; c < endcol; c++, n++) {
+			dbuf2[n].byte1 = str[c++].code;
+			dbuf2[n].byte2 = str[c].code;
+		}
+	} else
+# endif /* KTERM_MBCS */
+	{
+		if (endcol-col > 256)
+			dbuf = XtMalloc((endcol-col) * sizeof(char));
+		if (gset) {
+			for (c = col, n = 0; c < endcol; c++, n++) {
+				dbuf[n] = gsetmaponfont[gset]
+					    ? gsetmaponfont[gset][str[c].code]
+					    : str[c].code;
+			}
+		} else {
+			for (c = col, n = 0; c < endcol; c++, n++) {
+				dbuf[n] = ' ';
+			}
+		}
+	}
+
+	if (!(flags & BOLD) && !screen->normalGC)
+	    LoadOneFont(screen, True, screen->menu_font_number, fnum, False);
+	else if (flags & BOLD && !screen->normalboldGC)
+	    LoadOneFont(screen, True, screen->menu_font_number, fnum, True);
+	
 	if (flags & INVERSE) {
-		if (cursorstate && screen->reversecursorGC)
+		if (hilitecursor && screen->reversecursorGC)
 			gc = screen->reversecursorGC;
 		else if (flags & BOLD)
 			gc = screen->reverseboldGC;
 		else
 			gc = screen->reverseGC;
 	} else {
-		if (cursorstate && screen->cursorGC)
+		if (hilitecursor && screen->cursorGC)
 			gc = screen->cursorGC;
 		else if (flags & BOLD)
 			gc = screen->normalboldGC;
@@ -1159,44 +1209,59 @@ Boolean	oncursor;
 	}
 
 #ifdef KTERM_COLOR
-	if (!cursorstate && flags & (FORECOLORED|BACKCOLORED)) {
+	if (!hilitecursor && flags & (FORECOLORED|BACKCOLORED)) {
 		XGCValues	xgcv;
+		unsigned long	f, b;
+		f = flags&FORECOLORED ? screen->textcolor[FORECOLORNUM(flags)]
+				      : screen->foreground;
+		b = flags&BACKCOLORED ? screen->textcolor[BACKCOLORNUM(flags)]
+				      : term->core.background_pixel;
 		if (flags & INVERSE) {
-		    xgcv.background = flags&FORECOLORED ? screen->textcolor[FORECOLORNUM(flags)]: screen->foreground;
-		    xgcv.foreground = flags&BACKCOLORED ? screen->textcolor[BACKCOLORNUM(flags)]: term->core.background_pixel;
-		    XChangeGC(screen->display, gc, GCForeground|GCBackground, &xgcv);
+		    xgcv.foreground = b;
+		    xgcv.background = f;
 		} else {
-		    xgcv.foreground = flags&FORECOLORED ? screen->textcolor[FORECOLORNUM(flags)]: screen->foreground;
-		    xgcv.background = flags&BACKCOLORED ? screen->textcolor[BACKCOLORNUM(flags)]: term->core.background_pixel;
-		    XChangeGC(screen->display, gc, GCForeground|GCBackground, &xgcv);
+		    xgcv.foreground = f;
+		    xgcv.background = b;
 		}
+		XChangeGC(screen->display, gc, GCForeground|GCBackground, &xgcv);
 	}
 #endif /* KTERM_COLOR */
 
 	if (gset == GSET_GRAPH) {
-		int	col, X, Y = y;
+		int	col, X;
+		Pixmap	pm;
 		for (col = 0, X = x; col < n; col ++, X += FontWidth(screen)) {
-		    if (screen->graphics[dbuf[col].byte2]) {
-			XCopyPlane(screen->display,
-			    screen->graphics[dbuf[col].byte2],
-			    TextWindow(screen), gc,
+		    if ((pm = screen->graphics[dbuf[col]])
+		     || (pm = screen->graphics[' '])) {
+			XCopyPlane(screen->display, pm, TextWindow(screen), gc,
 			    0, 0, FontWidth(screen), FontHeight(screen),
-			    X, Y, 1);
+			    X, y, 1);
 		    }
 		}
 	} else {
 		int	Y = y + screen->linespace / 2 + screen->max_ascent;
 
-		XDrawImageString16(screen->display, TextWindow(screen), 
-			gc, x, Y, dbuf, n);
-		if ((flags & BOLD) && screen->enbolden)
-			XDrawString16(screen->display, TextWindow(screen), 
+#ifdef KTERM_MBCS
+		if (gset & MBCS) {
+			XDrawImageString16(screen->display, TextWindow(screen),
+				gc, x, Y, dbuf2, n);
+			if (flags & BOLD && screen->normalboldGC == screen->normalGC)
+			    XDrawString16(screen->display, TextWindow(screen),
+				gc, x + 1, Y, dbuf2, n);
+		} else
+#endif /* KTERM_MBCS */
+		{
+			XDrawImageString(screen->display, TextWindow(screen),
+				gc, x, Y, dbuf, n);
+			if (flags & BOLD && screen->normalboldGC == screen->normalGC)
+			    XDrawString(screen->display, TextWindow(screen),
 				gc, x + 1, Y, dbuf, n);
+		}
 		if (flags & UNDERLINE) 
-			XDrawLine(screen->display, TextWindow(screen), 
-				gc, x, Y+1, x+cols*FontWidth(screen), Y+1);
+		    XDrawLine(screen->display, TextWindow(screen),
+			gc, x, Y+1, x + (endcol-col) * FontWidth(screen), Y+1);
 	}
-	if (oncursor && !cursorstate) {
+	if (oncursor && !hilitecursor) {
 		screen->box->x = x;
 		screen->box->y = y + screen->linespace / 2;
 		XDrawLines (screen->display, TextWindow(screen),
@@ -1206,18 +1271,21 @@ Boolean	oncursor;
 	}
 
 #ifdef KTERM_COLOR
-	if (!cursorstate && flags & (FORECOLORED|BACKCOLORED)) {
+	if (!hilitecursor && flags & (FORECOLORED|BACKCOLORED)) {
 		XGCValues	xgcv;
 		if (flags & INVERSE) {
-		    xgcv.background = screen->foreground;
 		    xgcv.foreground = term->core.background_pixel;
-		    XChangeGC(screen->display, gc, GCForeground|GCBackground, &xgcv);
+		    xgcv.background = screen->foreground;
 		} else {
 		    xgcv.foreground = screen->foreground;
 		    xgcv.background = term->core.background_pixel;
-		    XChangeGC(screen->display, gc, GCForeground|GCBackground, &xgcv);
 		}
+		XChangeGC(screen->display, gc, GCForeground|GCBackground, &xgcv);
 	}
 #endif /* KTERM_COLOR */
+#ifdef KTERM_MBCS
+	if (dbuf2 != drawbuf2) XtFree((char *)dbuf2);
+#endif /* KTERM_MBCS */
+	if (dbuf != drawbuf) XtFree(dbuf);
 }
 #endif /* KTERM */
